==> haskell-microlens-platform-0.3.11-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-platform
version: 0.3.11
id: microlens-platform-0.3.11-9jaoxtWUbzK7prhiwO4LdS
key: microlens-platform-0.3.11-9jaoxtWUbzK7prhiwO4LdS
license: BSD-3-Clause
maintainer: Monadfix <hi@monadfix.io>
author: Edward Kmett, Artyom Kazak
homepage: http://github.com/monadfix/microlens
synopsis: Feature-complete microlens
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.
    .
    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.
category: Data, Lenses
abi: aec131494141c92e23879a6ca39fafec
exposed: True
exposed-modules:
    Lens.Micro.Platform Lens.Micro.Platform.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/microlens-platform-0.3.11
library-dirs: /usr/lib/ghc-8.6.4/site-local/microlens-platform-0.3.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/microlens-platform-0.3.11
hs-libraries: HSmicrolens-platform-0.3.11-9jaoxtWUbzK7prhiwO4LdS
depends:
    base-4.12.0.0 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    microlens-0.4.10-LVgmazyXGvNKvoQElrYSfS
    microlens-ghc-0.4.10-3WPL63hZTzx5JfoSe4avt0
    microlens-mtl-0.1.11.1-F46NcsxtAjc5NhO4kHlQKE
    microlens-th-0.4.2.3-2ty2TK3jSO111y1tN2Ao3p text-1.2.3.1
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock
haddock-html: /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-platform-0.3.11-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-platform
version: 0.3.11
id: microlens-platform-0.3.11-9Z3n9aCfPLc7gbTevYl9Ni
key: microlens-platform-0.3.11-9Z3n9aCfPLc7gbTevYl9Ni
license: BSD-3-Clause
maintainer: Monadfix <hi@monadfix.io>
author: Edward Kmett, Artyom Kazak
homepage: http://github.com/monadfix/microlens
synopsis: Feature-complete microlens
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.
    .
    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.
category: Data, Lenses
abi: 668066c881c3894dc65dea2e67db9188
exposed: True
exposed-modules:
    Lens.Micro.Platform Lens.Micro.Platform.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/microlens-platform-0.3.11
library-dirs: /usr/lib/ghc-8.6.4/site-local/microlens-platform-0.3.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/microlens-platform-0.3.11
hs-libraries: HSmicrolens-platform-0.3.11-9Z3n9aCfPLc7gbTevYl9Ni
depends:
    base-4.12.0.0 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    microlens-0.4.10-LVgmazyXGvNKvoQElrYSfS
    microlens-ghc-0.4.10-3WPL63hZTzx5JfoSe4avt0
    microlens-mtl-0.1.11.1-6U2K56DzIyY4kKXnpNGylh
    microlens-th-0.4.2.3-2ty2TK3jSO111y1tN2Ao3p text-1.2.3.1
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock
haddock-html: /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
